@@ -59,10 +59,11 @@ Dev API
    Storage
 """
 
-__version__ = "0.30.1"  # denote a pre-release for 0.1.0 with 0.1a1
-import atexit
+__version__ = "0.30.3"  # denote a pre-release for 0.1.0 with 0.1a1
+
 from os import name as _os_name
 
+from . import _check_versions  # noqa
 from ._close import close  # noqa
 from ._delete import delete  # noqa
 from ._info import info  # noqa
@@ -76,15 +77,6 @@ from ._settings_instance import InstanceSettings, Storage  # noqa
 from ._settings_user import UserSettings  # noqa
 from ._setup_user import login, signup  # noqa
 
-
-# close the database session
-@atexit.register
-def cleanup_session():
-    instance = settings._instance_settings
-    if instance is not None and instance._session is not None:
-        instance._session.close()
-
-
 # hide the supabase error in a thread on windows
 if _os_name == "nt":
     from sys import version_info as _python_version
